@@ -2,7 +2,7 @@
 """
 @Author: ChenCheng
 @Date: 2022-03-18 10:12:12
-@LastEditTime: 2022-07-22 10:38:15
+@LastEditTime: 2022-07-25 11:42:53
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -205,12 +205,12 @@ class LaunchGoodsListHandler(TopBaseHandler):
                 if "item" in resq["items_seller_list_get_response"]["items"].keys():
                     goods_list = resq["items_seller_list_get_response"]["items"]["item"]
             else:
-                invoke_result_data["data"] = {"is_launch": act_info_dict['is_launch'], "page_info": {}}
+                invoke_result_data["data"] = {"is_launch": act_info_dict['is_throw'], "page_info": {}}
                 return invoke_result_data
         if len(goods_list) > 0:
             launch_goods_list = SevenHelper.merge_dict_list(launch_goods_list, "goods_id", goods_list, "num_iid", "pic_url,title")
         page_info = PageInfo(page_index, page_size, total, launch_goods_list)
-        invoke_result_data["data"] = {"is_launch": act_info_dict['is_launch'], "page_info": page_info.__dict__}
+        invoke_result_data["data"] = {"is_launch": act_info_dict['is_throw'], "page_info": page_info.__dict__}
         return invoke_result_data
 
 
@@ -329,7 +329,7 @@ class GetLaunchPlanStatusHandler(TopBaseHandler):
     @return {*}
     @last_editors: CaiYouBin
     """
-    @filter_check_params("app_id,act_id")
+    @filter_check_params("act_id")
     def get_async(self):
         act_id = int(self.get_param("act_id", 0))
         access_token = self.get_param("access_token")
@@ -379,7 +379,7 @@ class GetLaunchPlanStatusHandler(TopBaseHandler):
 
         except Exception as ex:
             self.logging_link_error("GetLaunchActionInfo:" + traceback.format_exc())
-            invoke_result_data.success = False
+            invoke_result_data["success"] = False
             if "submsg" in str(ex):
                 content_list = str(ex).split()
                 for content in content_list:
@@ -465,6 +465,9 @@ class CanLaunchGoodsListHandler(TopBaseHandler):
         page_size = self.get_param("page_size", 20)
 
         resp = self.get_goods_list(page_index, page_size, goods_name, order_tag, order_by, access_token)
+        if "items_onsale_get_response" not in resp or "items" not in resp["items_onsale_get_response"]:
+            return self.reponse_json_success([])
+
         goods_id_list = [str(goods["num_iid"]) for goods in resp["items_onsale_get_response"]["items"]["item"]]
         goods_id_str_list = ','.join(["'%s'" % str(item) for item in goods_id_list])
         goods_id_in_condition = f"goods_id in ({goods_id_str_list})"
@@ -496,6 +499,47 @@ class CanLaunchGoodsListHandler(TopBaseHandler):
 
         return self.reponse_json_success(resp)
 
+    def get_goods_list(self, page_index, page_size, goods_name, order_tag, order_by, access_token):
+        """
+        :description: 导入商品列表（获取当前会话用户出售中的商品列表）
+        :param page_index：页索引
+        :param page_size：页大小
+        :param goods_name：商品名称
+        :param order_tag：order_tag
+        :param order_by：排序类型
+        :param access_token：access_token
+        :return 
+        :last_editors: HuangJingCan
+        """
+        try:
+            app_key, app_secret = self.get_app_key_secret()
+            top.setDefaultAppInfo(app_key, app_secret)
+            req = top.api.ItemsOnsaleGetRequest()
+
+            req.fields = "num_iid,title,nick,price,input_str,property_alias,sku,props_name,pic_url"
+            req.page_no = page_index + 1
+            req.page_size = page_size
+            if goods_name != "":
+                req.q = goods_name
+            req.order_by = order_tag + ":" + order_by
+
+            resp = req.getResponse(access_token)
+            if resp:
+                resp["pageSize"] = page_size
+                resp["pageIndex"] = page_index
+
+            self.logging_link_info(str(resp) + "【access_token】：" + self.get_taobao_param().access_token)
+            return resp
+        except Exception as ex:
+            self.logging_link_error(traceback.format_exc())
+            if "submsg" in str(ex):
+                content_list = str(ex).split()
+                for content in content_list:
+                    if "submsg=该子帐号无此操作权限" in content:
+                        return self.return_dict_error("NoPower", content[len("submsg="):])
+                    if "submsg=" in content:
+                        return self.return_dict_error("Error", content[len("submsg="):])
+
 
 class GetLaunchProgressHandler(SevenBaseHandler):
     """
