@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-04-16 14:38:22
-@LastEditTime: 2022-07-13 10:08:30
+@LastEditTime: 2022-07-14 17:24:22
 @LastEditors: HuangJianYi
 :Description: 潮玩盲盒基础路由
 """
@@ -22,6 +22,7 @@ def seven_cloudapp_ppmt_route():
         (r"/", IndexHandler),
         # 千牛端接口
         (r"/server/saas_custom", base_s.SaasCustomHandler),
+        (r"/server/left_ad_list", app_s.LeftAdListHandler),  #左侧广告
         (r"/server/login", user_s.LoginHandler),
         (r"/server/gear_log", user_s.GearLogHandler),
         (r"/server/user_list", user_s.UserListHandler),
@@ -68,7 +69,7 @@ def seven_cloudapp_ppmt_route():
         (r"/server/prize_roster_export", order_s.PrizeRosterListExportHandler),
         (r"/server/report_info", report_s.ReportInfoHandler),
         (r"/server/report_list2", report_s.ReportInfoListHandler),
-        (r"/server/send_sms", sms_s.SendSmsHandler),
+        (r"/server/send_sms", app_s.SendSmsHandler),
         (r"/server/series", series_s.SeriesHandler),
         (r"/server/series_del", series_s.SeriesDelHandler),
         (r"/server/series_list", series_s.SeriesListHandler),
@@ -93,6 +94,7 @@ def seven_cloudapp_ppmt_route():
         (r"/server/save_launch_goods_status", launch_s.UpdateLaunchGoodsStatusHandler),  #保存更改投放商品的状态
         (r"/server/launch_goods_list", launch_s.LaunchGoodsListHandler),  #投放商品列表
         (r"/server/async_launch_goods", launch_s.AsyncLaunchGoodsStatusHandler),  #同步投放商品列表
+
         # 2.0
         (r"/server/get_power_menu", power_s.GetPowerMenuHandler),
         (r"/server/task", task_s.TaskSaveHandler),
